<?php
/**
 * @file
 * Google_plus_feeds.blocks.inc.
 */

/**
 * Gets google plus posts based on google plus account settings.
 *
 * @return array
 *   Array of google plus posts ready to be sent to theme_item_list().
 *   Empty array if no posts could be found.
 *   This can happen if the credentials are not good.
 */
function _google_plus_feeds_blocks_view_posts() {
  $google_plus_id = variable_get('google_plus_feeds_account_id');
  $google_plus_api_key = variable_get('google_plus_feeds_api_key');

  // API the url to get google posts.
  // Display maximum 3 google feeds.
  $request_url = format_string(
    variable_get(
      'google_plus_feeds_api_url',
      'https://www.googleapis.com/plus/v1/people/!google_account_id/activities/public?maxResults=!posts_count&key=!google_api_key'
    ),
    array(
      '!google_account_id' => $google_plus_id,
      '!posts_count' => variable_get('google_plus_feeds_statuses_count', 3),
      '!google_api_key' => $google_plus_api_key,
    )
  );

  // Get posts from cache.
  // SET google_plus_feeds_posts_cache_length to 0, the feeds will not stored
  // in cache. Refresh feeds after every 15 mins. This is done to increase the
  // site performance.
  if (REQUEST_TIME - variable_get('google_plus_feeds_posts_cache_set_time') >
    variable_get('google_plus_feeds_posts_cache_length', 900)) {
    // Get google+ posts from cache.
    $cache = cache_get('google_plus_feeds_posts');
    if ($cache && isset($cache->data)) {
      $google_posts = $cache->data;
    }
    else {
      watchdog(
        'mp_google_posts',
        'Unable to get Google+ posts from cache.',
        array(),
        WATCHDOG_ERROR
      );
    }
  }

  if (empty($google_posts)) {
    $response = drupal_http_request($request_url);

    if ($response->code != 200) {
      $cache = cache_get('google_plus_feeds_posts');
      if ($cache && isset($cache->data)) {
        $google_posts = $cache->data;
      }
      else {
        watchdog(
          'mp_google_posts',
          'Unable to get Google+ posts from Google account.',
          array(),
          WATCHDOG_ERROR
        );
        $google_posts = array();
      }
    }
    else {
      $google_posts = json_decode($response->data, TRUE);
      // Set cache for future use if response not correct.
      cache_set('google_plus_feeds_posts', $google_posts);
      variable_set('google_plus_feeds_posts_cache_set_time', REQUEST_TIME);
    }
  }

  $google_plus_posts_list = array();
  if (!empty($google_posts['items'])) {
    foreach ($google_posts['items'] as $value) {
      $google_plus_posts_list[] = array(
        'data' => theme(
          'google_plus_feeds_post',
          array(
            'title' => $value['title'],
            'url' => $value['url'],
          )
        ),
      );
    }
  }

  // Add see more posts link to redirect to google account post page.
  if (!empty($google_plus_id)) {
    $google_plus_posts_list[] = l(
      t('See more posts'),
      format_string(
        variable_get(
          'google_plus_feeds_posts_url',
          'https://plus.google.com/!google_account_id/posts'
        ),
        array(
          '!google_account_id' => variable_get('google_plus_feeds_account_id'),
        )
      ),
      array(
        'attributes' => array(
          'class' => array('more-post'),
          'target' => '_blank',
        ),
      )
    );
  }

  return $google_plus_posts_list;
}
